@@ -2,12 +2,22 @@ use strict;
 use warnings;
 
 package Pod::POM::View::TextBasic;
-our $VERSION = 0.1;
+our $VERSION = 0.2;
 
 use base 'Pod::POM::View::Text';
 
 our $DROPS = 1;
 
+sub view_for { return maybe_stopwords(@_); }
+
+sub view_begin { return maybe_stopwords(@_); }
+
+sub maybe_stopwords {
+    my ($format, $text) = $_[1] =~ /^\s*\=\w+\s+(\S+)\s+(.*?)\s*$/si;
+    $text =~ s/\s+/ /g;
+    return $format =~ /^(stopwords?|spelling|allow|allow_words|allowed_words)$/gi? $text : '';
+}
+
 sub view_seq_bold { return $_[1]; }
 
 sub view_seq_italic { return $_[1]; }
