@@ -6,7 +6,7 @@ package Pod::Spelling;
 our $VERSION = 0.6; # Catch undefined
 
 use Pod::POM;
-
+require Pod::POM::View::TextBasic;
 use warnings::register;
 use Carp;
 
@@ -16,16 +16,19 @@ sub new {
 		(ref($_[0])? shift : {@_})
 	);
 
-	Pod::POM->default_view( 'Pod::POM::View::TextBasic' )
-		or confess $Pod::POM::ERROR;
-	
+	# Pod::POM->default_view( 'Pod::POM::View::TextBasic' )
+	# 	or confess $Pod::POM::ERROR;
+
 	my $self = bless {
 		%$args,
 		_parser => Pod::POM->new,
+		_temp_stoplist => [],
 	}, $class;
 	
 	$self->{skip_paths_matching} ||= [];
 
+	$self->{view} ||= 'Pod::POM::View::TextBasic';
+
 	# Allow a single word to be allowed:
 	if ($self->{allow_words} and not ref $self->{allow_words}){
 		$self->{allow_words} = [ $self->{allow_words} ];
@@ -141,6 +144,7 @@ sub check_file {
 
 	# Crude test to allow package names:
 	{
+		# Hope it is not too large.
 		open my $IN, $path or confess "$! - $path";
 		read $IN, my $content, -s $IN;
 		close $IN;
@@ -155,6 +159,11 @@ sub check_file {
 			} @packages
 		);
 	}
+
+	# To support '=for stopwords', we could create yet another parser, 
+	# and reparse the document, but not sure why that would be better
+	# than this:
+
 		
     my $pom = $self->{_parser}->parse_file($path)
     	or confess $self->{_parser}->error();
@@ -162,7 +171,18 @@ sub check_file {
 	my $code = $self->{spell_check_callback};
 	
 	my $line = 0;
-	foreach my $text ( split/[\n\r\f]+/, scalar $pom->content()) {
+	foreach my $node ($pom->content){
+
+		if ($node->type() =~ /^(begin|for)$/){
+			my $allowed_line = $node->present( $self->{view} );
+			my @stoplist = split /\s/, $allowed_line;
+			$self->_add_temporary_stoplist( @stoplist );
+			next;
+		}
+
+		my $text = $node->present( $self->{view} );
+		$text =~ s/[\n\r\f]+/ /sg;
+
 		$text = $self->_clean_text( $text );
 		my @err = $self->$code( $text );
 		
@@ -194,6 +214,8 @@ sub check_file {
 		$line ++;
 	}
 
+	$self->_remove_temporary_stoplist;
+
 	return @rv;
 }
 
@@ -208,6 +230,27 @@ sub skip_paths_matching {
 	return @{ $self->{skip_paths_matching} };
 }
 
+sub _add_temporary_stoplist {
+	my ($self, @stoplist) = @_;
+	my $dict = { map {$_=>1} @{$self->{allow_words}} };
+	my @new;
+	foreach my $word (@stoplist){
+		push @new, $word if not exists $dict->{$word};
+	}
+	push @{ $self->{_temp_stoplist} }, \@new;
+	$self->add_allow_words( @new );
+}
+
+sub _remove_temporary_stoplist {
+	my ($self, @stoplist) = @_;
+	return if not scalar @{ $self->{_temp_stoplist} };
+	my $remove = { map {$_=>1} pop @{ $self->{_temp_stoplist} } };
+	my @allowed;
+	foreach my $word (@{ $self->{allow_words} }){
+		push @allowed, $word if not exists $remove->{$word};
+	}
+}
+
 1;
 
 =encoding utf8
